@@ -2,7 +2,6 @@
 #define CONFIGURATION_H
 
 #include "Tools.h"
-#include "Exception.h"
 
 //----------------------------------------------------------------------------
 class Configuration
@@ -15,8 +14,7 @@ class Configuration
     ~Configuration();
 
     //------------------------------------------------------------------------
-    void searchDataDir()
-        throw (Exception);
+    void searchDataDir();
 
     //------------------------------------------------------------------------
     inline const char *getDataDir() const
@@ -25,7 +23,6 @@ class Configuration
     }
 
   protected:
-
     //------------------------------------------------------------------------
     const char *m_dataDir;
 };
