@@ -5,18 +5,22 @@
 #include <sys/stat.h>
 #include <unistd.h>
 
-#include "SyscallException.h"
-
 //----------------------------------------------------------------------------
 namespace SYSTEM_CALL
 {
     //------------------------------------------------------------------------
-    void stat(const char *file, struct stat *buf)
-        throw (SyscallException);
+    /**
+     * Calls the system's stat() function.
+     * @throw ISyscallException if the call to stat() failed.
+     */
+    void stat(const char *file, struct stat *buf);
 
     //------------------------------------------------------------------------
-    void lstat(const char *file, struct stat *buf)
-        throw (SyscallException);
+    /**
+     * Calls the system's lstat() function.
+     * @throw ISyscallException if the call to lstat() failed.
+     */
+    void lstat(const char *file, struct stat *buf);
 }
 
 #endif //SYSTEMCALLS_H
