@@ -1,6 +1,7 @@
 #ifndef XMLPARSER_H
 #define XMLPARSER_H
 
+#include "Tools.h"
 #include "XMLElements.h"
 
 //----------------------------------------------------------------------------
@@ -12,12 +13,11 @@ class XMLParser
     ~XMLParser();
 
     //------------------------------------------------------------------------
-    XMLNode *parse(const char *file) throw (Exception);
-    void parse(const char *file, XMLNode &root) throw (Exception);
+    XMLNode *parse(const char *file);
+    void parse(const char *file, XMLNode &root);
 
-  private:
     //------------------------------------------------------------------------
-    class XMLParserPImpl *m_pImpl;
+    DECLARE_PIMPL;
 };
 
 #endif //XMLPARSER_H
