@@ -444,6 +444,12 @@ bool SDL_TOOLS::inside(const Sint16 x, const Sint16 y, const SDL_Rect &r)
     return (r.x <= x) && (x < r.x + r.w) && (r.y <= y) && (y < r.y + r.h);
 }
 
+//----------------------------------------------------------------------------
+bool SDL_TOOLS::inside(const Sint16 x, const Sint16 y, const SDL_Surface *s)
+{
+    return (x >= 0) && (x < s->w) && (y >= 0) && (y < s->h);
+}
+
 //----------------------------------------------------------------------------
 bool SDL_TOOLS::intersect(const SDL_Rect &r1, const SDL_Rect &r2,
                           SDL_Rect &clip)
