@@ -269,9 +269,9 @@ class GameControlBase
     }
 
     //------------------------------------------------------------------------
-    inline unsigned getPlayerFuel() const
+    inline double getPlayerInitialFuel() const
     {
-        return m_playerFuel;
+        return m_playerInitialFuel;
     }
 
     //------------------------------------------------------------------------
@@ -294,10 +294,6 @@ class GameControlBase
     /// Initiates the bonus-to-score adding.
     void initAddBonusToScore();
 
-    inline unsigned getPlayerFuelDecrement() const
-    {
-        return m_playerFuelDecrement;
-    }
 
     //------------------------------------------------------------------------
     inline void resetFrameCounter()
@@ -473,6 +469,7 @@ class GameControlBase
     void onCollision(ProjectileBase *projectile);
 
     void onCollision(ProjectileBase *projectile, MortarBase *mortar);
+    void onCollision(ProjectileBase *projectile, SAMBatteryBase *sam);
     void onCollision(ProjectileBase *projectile, SwitchBase *s);
     void onCollision(ProjectileBase *projectile, Tank *tank);
     void onCollision(ProjectileBase *projectile, TurretBase *turret);
@@ -512,11 +509,8 @@ class GameControlBase
     /// The player's ship id. It remains constant during a level.
     unsigned m_playerId;
 
-    /// The fuel for the player's ship.
-    unsigned m_playerFuel;
-
-    /// The fuel decrement value for each Ship::decFuel() call.
-    unsigned m_playerFuelDecrement;
+    /// The initial fuel percentage for the player's ship.
+    double m_playerInitialFuel;
 
 
     /// The ship's initial x position.
