@@ -32,15 +32,33 @@ class PlayerStatus
 
 
     //------------------------------------------------------------------------
-    inline void addToScore(unsigned points)
+    inline void addScore(const unsigned points)
+    {
+        m_score += 1.0*points;
+    }
+
+    //------------------------------------------------------------------------
+    inline void addScore(const double points)
     {
         m_score += points;
     }
 
     //------------------------------------------------------------------------
-    inline size_t getScore() const
+    inline void decScore(const unsigned points)
     {
-        return m_score;
+        m_score -= 1.0*points;
+    }
+
+    //------------------------------------------------------------------------
+    inline void decScore(const double points)
+    {
+        m_score -= points;
+    }
+
+    //------------------------------------------------------------------------
+    inline unsigned getScore() const
+    {
+        return (unsigned)rint(m_score);
     }
 
     //------------------------------------------------------------------------
@@ -107,7 +125,7 @@ class PlayerStatus
   private:
 
     //------------------------------------------------------------------------
-    unsigned m_score;
+    double m_score;
     unsigned m_lifes;
     unsigned m_bonus;
     std::string m_message;
