@@ -1,9 +1,8 @@
 #ifndef SCORETABLE_H
 #define SCORETABLE_H
 
-#include <Tools.h>
-
-class Crate;
+#include "Tools.h"
+#include "ObjectFwd.h"
 
 //----------------------------------------------------------------------------
 /**
