@@ -90,7 +90,14 @@ void GameControlBase::Running::onPreUpdate(GameControlBase *game)
 
     if (landedPlatform != NULL && landedPlatform->isFuelPlatform())
     {
-        ship->incFuel(5, game->getPlayerFuel());
+        if (ship->getFuel() < ship->getFuelCapacity() &&
+            PlayerStatus::getInstance()->getScore() > 0)
+        {
+            PlayerStatus::getInstance()->decScore(
+                1.0 * landedPlatform->getFuelCost() /
+                SDLFrameRate::getFrameRate());
+            ship->addFuel(10);
+        }
     }
 }
 
@@ -153,13 +160,12 @@ void GameControlBase::Running::onShipLanded(
             pickup = true;
             if (crateToPickup->getValue() == 0)
             {
-                ship->setFuel(game->getPlayerFuel());
+                ship->setFuel(ship->getFuelCapacity());
             }
             else
             {
-                unsigned amount = ship->getFuel() +
-                    crateToPickup->getValue() * SDLFrameRate::getFrameRate();
-                ship->setFuel(MIN(amount, game->getPlayerFuel()));
+                ship->addFuel(
+                    crateToPickup->getValue() * SDLFrameRate::getFrameRate());
             }
             break;
 
@@ -169,7 +175,7 @@ void GameControlBase::Running::onShipLanded(
 
         if (pickup)
         {
-            PlayerStatus::getInstance()->addToScore(
+            PlayerStatus::getInstance()->addScore(
                 ScoreTable::getInstance()->getCratePickUp(crateToPickup));
             SoundInterface::getInstance()->onCratePickUp();
 
@@ -295,25 +301,25 @@ void GameControlBase::ExplosionDelay::onPreUpdate(GameControlBase *game)
 //----------------------------------------------------------------------------
 void GameControlBase::AddFuelToScore::onPreUpdate(GameControlBase *game)
 {
-   if (!game->getPlayerShip()->decFuel(game->getPlayerFuelDecrement()))
-   {
-       if (game->hasFrameCounterReachedLimit())
-       {
-           game->resetFrameCounter();
+    if (!game->getPlayerShip()->decFuel(50))
+    {
+        if (game->hasFrameCounterReachedLimit())
+        {
+            game->resetFrameCounter();
 
-           PlayerStatus::getInstance()->addToScore(
-               ScoreTable::getInstance()->getSpareFuelStep());
-       }
-   }
-   else if (PlayerStatus::getInstance()->getBonus() > 0)
-   {
-       game->initAddBonusToScore();
-       game->setState(AddBonusToScore::getInstance());
-   }
-   else
-   {
-       game->setState(Final::getInstance());
-   }
+            PlayerStatus::getInstance()->addScore(
+                ScoreTable::getInstance()->getSpareFuelStep());
+        }
+    }
+    else if (PlayerStatus::getInstance()->getBonus() > 0)
+    {
+        game->initAddBonusToScore();
+        game->setState(AddBonusToScore::getInstance());
+    }
+    else
+    {
+        game->setState(Final::getInstance());
+    }
 }
 
 
@@ -327,7 +333,7 @@ void GameControlBase::AddBonusToScore::onPreUpdate(GameControlBase *game)
         PlayerStatus *ps = PlayerStatus::getInstance();
         if (ps->getBonus() > 0)
         {
-            ps->addToScore(1);
+            ps->addScore(1u);
             ps->decBonus(1);
         }
         else
@@ -419,8 +425,7 @@ GameControlBase::GameControlBase()
 {
     m_player = NULL;
     m_playerId = 0;
-    m_playerFuel = 0;
-    m_playerFuelDecrement = 0;
+    m_playerInitialFuel = 1.0;
 
     m_initialXPosition = 0;
     m_initialYPosition = 0;
@@ -525,8 +530,8 @@ void GameControlBase::initStartPosition(const XMLNode *startPositionNode)
     // Levels for the test suite may not have any properties.
     if (!startPositionNode->hasProperties())  return;
 
-    m_playerFuel = SDLFrameRate::getFrameRate() *
-        startPositionNode->getUnsignedProperty("fuel", 100);
+    m_playerInitialFuel = 
+        startPositionNode->getUnsignedProperty("fuel", 100) / 100.0;
 
     createPlayerShip();
 
@@ -604,7 +609,7 @@ void GameControlBase::onCollision(Ship *ship, MortarBase *mortar)
     do_explode(ship);
     do_explode(mortar);
 
-    PlayerStatus::getInstance()->addToScore(
+    PlayerStatus::getInstance()->addScore(
         ScoreTable::getInstance()->getMortarShot());
 
     initExplosion();
@@ -627,7 +632,7 @@ void GameControlBase::onCollision(Ship *ship, SAMBatteryBase *sam)
     do_explode(ship);
     do_explode(sam);
 
-    PlayerStatus::getInstance()->addToScore(
+    PlayerStatus::getInstance()->addScore(
         ScoreTable::getInstance()->getSAMBatteryShot());
 
     initExplosion();
@@ -640,7 +645,7 @@ void GameControlBase::onCollision(Ship *ship, Tank *tank)
     do_explode(ship);
     do_explode(tank);
 
-    PlayerStatus::getInstance()->addToScore(
+    PlayerStatus::getInstance()->addScore(
         ScoreTable::getInstance()->getTankShot());
 
     initExplosion();
@@ -653,7 +658,7 @@ void GameControlBase::onCollision(Ship *ship, TurretBase *turret)
     do_explode(ship);
     do_explode(turret);
 
-    PlayerStatus::getInstance()->addToScore(
+    PlayerStatus::getInstance()->addScore(
         ScoreTable::getInstance()->getTurretShot());
 
     initExplosion();
@@ -675,7 +680,7 @@ void GameControlBase::onCollision(Missile *missile, Grenade *grenade)
 
     if (grenade->getCreatorId() == getPlayerShipId())
     {
-        PlayerStatus::getInstance()->addToScore(
+        PlayerStatus::getInstance()->addScore(
             ScoreTable::getInstance()->getMissileShot());
     }
 }
@@ -688,7 +693,7 @@ void GameControlBase::onCollision(Missile *missile, MortarBase *mortar)
 
     if (missile->getCreatorId() == getPlayerShipId())
     {
-        PlayerStatus::getInstance()->addToScore(
+        PlayerStatus::getInstance()->addScore(
             ScoreTable::getInstance()->getMortarShot());
     }
 }
@@ -701,7 +706,7 @@ void GameControlBase::onCollision(Missile *missile, ProjectileBase *projectile)
 
     if (projectile->getCreatorId() == getPlayerShipId())
     {
-        PlayerStatus::getInstance()->addToScore(
+        PlayerStatus::getInstance()->addScore(
             ScoreTable::getInstance()->getMissileShot());
     }
 }
@@ -714,7 +719,7 @@ void GameControlBase::onCollision(Missile *missile, SAMBatteryBase *sam)
 
     if (missile->getCreatorId() == getPlayerShipId())
     {
-        PlayerStatus::getInstance()->addToScore(
+        PlayerStatus::getInstance()->addScore(
             ScoreTable::getInstance()->getSAMBatteryShot());
     }
 }
@@ -734,7 +739,7 @@ void GameControlBase::onCollision(Missile *missile, Tank *tank)
 
     if (missile->getCreatorId() == getPlayerShipId())
     {
-        PlayerStatus::getInstance()->addToScore(
+        PlayerStatus::getInstance()->addScore(
             ScoreTable::getInstance()->getTankShot());
     }
 }
@@ -747,7 +752,7 @@ void GameControlBase::onCollision(Missile *missile, TurretBase *turret)
 
     if (missile->getCreatorId() == getPlayerShipId())
     {
-        PlayerStatus::getInstance()->addToScore(
+        PlayerStatus::getInstance()->addScore(
             ScoreTable::getInstance()->getTurretShot());
     }
 }
@@ -767,7 +772,7 @@ void GameControlBase::onCollision(Grenade *grenade, MortarBase *mortar)
 
     if (grenade->getCreatorId() == getPlayerShipId())
     {
-        PlayerStatus::getInstance()->addToScore(
+        PlayerStatus::getInstance()->addScore(
             ScoreTable::getInstance()->getMortarShot());
     }
 }
@@ -787,7 +792,7 @@ void GameControlBase::onCollision(Grenade *grenade, Tank *tank)
 
     if (grenade->getCreatorId() == getPlayerShipId())
     {
-        PlayerStatus::getInstance()->addToScore(
+        PlayerStatus::getInstance()->addScore(
             ScoreTable::getInstance()->getTankShot());
     }
 }
@@ -800,7 +805,7 @@ void GameControlBase::onCollision(Grenade *grenade, TurretBase *turret)
 
     if (grenade->getCreatorId() == getPlayerShipId())
     {
-        PlayerStatus::getInstance()->addToScore(
+        PlayerStatus::getInstance()->addScore(
             ScoreTable::getInstance()->getTurretShot());
     }
 }
@@ -823,12 +828,28 @@ void GameControlBase::onCollision(ProjectileBase *projectile,
 
         if (projectile->getCreatorId() == getPlayerShipId())
         {
-            PlayerStatus::getInstance()->addToScore(
+            PlayerStatus::getInstance()->addScore(
                 ScoreTable::getInstance()->getMortarShot());
         }
     }
 }
 
+//----------------------------------------------------------------------------
+void GameControlBase::onCollision(ProjectileBase *projectile, SAMBatteryBase *sam)
+{
+    do_explode(projectile);
+    if (sam->decAndTestHitPoints())
+    {
+        do_explode(sam);
+
+        if (projectile->getCreatorId() == getPlayerShipId())
+        {
+            PlayerStatus::getInstance()->addScore(
+                ScoreTable::getInstance()->getSAMBatteryShot());
+        }
+    }
+}
+
 //----------------------------------------------------------------------------
 void GameControlBase::onCollision(ProjectileBase *projectile, SwitchBase *s)
 {
@@ -846,7 +867,7 @@ void GameControlBase::onCollision(ProjectileBase *projectile, Tank *tank)
 
         if (projectile->getCreatorId() == getPlayerShipId())
         {
-            PlayerStatus::getInstance()->addToScore(
+            PlayerStatus::getInstance()->addScore(
                 ScoreTable::getInstance()->getTankShot());
         }
     }
@@ -863,7 +884,7 @@ void GameControlBase::onCollision(ProjectileBase *projectile,
 
         if (projectile->getCreatorId() == getPlayerShipId())
         {
-            PlayerStatus::getInstance()->addToScore(
+            PlayerStatus::getInstance()->addScore(
                 ScoreTable::getInstance()->getTurretShot());
         }
     }
@@ -878,42 +899,48 @@ void GameControlBase::handleEvents(const XMLNode *node)
     const XMLProperty *prop = NULL;
     std::vector<unsigned> ids;
 
-    // Activate laser barriers?
+    // Activate an object?
     prop = node->getProperty("activate");
     if (prop)
     {
         STRING_TOOLS::toUnsignedVector(prop->getValue(), ids);
         for (size_t i=0; i<ids.size(); i++)
         {
-            Barrier *barrier = dynamic_cast<Barrier*>(
-                ObjectRepository::getInstance()->getObject(ids[i]));
-            if (barrier)  barrier->activate();
+            AnimatedDecorationBase *object =
+                dynamic_cast<AnimatedDecorationBase*>(
+                    ObjectRepository::getInstance()->getObject(ids[i]));
+
+            if (object)  object->activate();
         }
     }
 
-    // Deactivate laser barriers?
+    // Deactivate an object?
     prop = node->getProperty("deactivate");
     if (prop)
     {
         STRING_TOOLS::toUnsignedVector(prop->getValue(), ids);
         for (size_t i=0; i<ids.size(); i++)
         {
-            Barrier *barrier = dynamic_cast<Barrier*>(
-                ObjectRepository::getInstance()->getObject(ids[i]));
-            if (barrier)  barrier->deactivate();
+            AnimatedDecorationBase *object =
+                dynamic_cast<AnimatedDecorationBase*>(
+                    ObjectRepository::getInstance()->getObject(ids[i]));
+
+            if (object)  object->deactivate();
         }
     }
 
-    // Toggle laser barriers?
+    // Toggle an object?
     prop = node->getProperty("toggle");
     if (prop)
     {
         STRING_TOOLS::toUnsignedVector(prop->getValue(), ids);
         for (size_t i=0; i<ids.size(); i++)
         {
-            Barrier *barrier = dynamic_cast<Barrier*>(
-                ObjectRepository::getInstance()->getObject(ids[i]));
-            if (barrier)  barrier->toggle();
+            AnimatedDecorationBase *object =
+                dynamic_cast<AnimatedDecorationBase*>(
+                    ObjectRepository::getInstance()->getObject(ids[i]));
+
+            if (object)  object->toggle();
         }
     }
 
@@ -1075,7 +1102,8 @@ void GameControlBase::resetPlayerShip()
     m_player->setExplode(false);
     m_player->resetPosition(
         m_initialXPosition, m_initialYPosition, m_homePlatformId > 0);
-    m_player->setFuel(getPlayerFuel());
+    m_player->setFuel(
+        (unsigned)(m_player->getFuelCapacity() * getPlayerInitialFuel()));
 }
 
 //----------------------------------------------------------------------------
@@ -1108,25 +1136,9 @@ void GameControlBase::initAddFuelToScore()
     //
     // A fuel of 50 seconds thus has to decrement 25 fuel units in every frame
     // and the score shall only be incremented every second frame.
-    //
-    // This way, the speed of the fuel-to-score adding
-    // is not depending on the value of the ship's initial fuel.
 
-    unsigned playerFuelReference = 100 * SDLFrameRate::getFrameRate();
-    unsigned ratio = playerFuelReference / getPlayerFuel();
-    if (ratio == 0)
-    {
-        ratio = 1;
-    }
-
-    // @todo: Was 50 @96fps and should be 37.5 @72fps.
-    //        But since the friction effect is lower, we use 40 here
-    //        to keep the fuel bonus nearly constant.
-    //        A clean solution depends on a framerate-independend
-    //        implementation of the friction model.
-    m_playerFuelDecrement = 40 / ratio;
     resetFrameCounter();
-    setFrameCounterLimit(ratio);
+    setFrameCounterLimit(SDLFrameRate::getFrameRate() / 16);
 
     SoundInterface::getInstance()->onAddFuelToScore();
 }
@@ -1198,7 +1210,7 @@ void GameControlBase::unloadCrate()
         assert(m_crateToUnload == NULL);
         m_crateToUnload = m_player->popCrate();
 
-        PlayerStatus::getInstance()->addToScore(
+        PlayerStatus::getInstance()->addScore(
             ScoreTable::getInstance()->getCrateRescued(m_crateToUnload));
         SoundInterface::getInstance()->onCrateUnload();
 
@@ -1244,13 +1256,22 @@ void GameControlBase::unloadCrate()
 //----------------------------------------------------------------------------
 void GameControlBase::update()
 {
-    updateBonus();
+    try
+    {
+        updateBonus();
 
-    onPreUpdate();
-    PlayGround::getInstance()->update();
-    onPostUpdate();
+        onPreUpdate();
+        PlayGround::getInstance()->update();
+        onPostUpdate();
 
-    //GameRecorder::getInstance()->writeFrame();
+        //GameRecorder::getInstance()->writeFrame();
+    }
+    catch (Exception &e)
+    {
+        std::cerr << "Critical runtime error during the game!" << std::endl
+                  << e << "." << std::endl;
+        throw;
+    }
 }
 
 
