@@ -427,10 +427,18 @@ unsigned PlayGround::getFriction(const SDL_Rect &r) const
 bool PlayGround::collidesWith(const ObjectBase *object) const
 {
     const SDL_Rect &objPos = object->getPosition();
+
+    // Catch objects lying fully or partially outside of the playground.
+    SDL_Rect tmpPos = { 0, 0, 0, 0 };
+    if (!SDL_TOOLS::intersect(getBoundingBox(), objPos, tmpPos) ||
+        !SDL_TOOLS::equal(objPos, tmpPos))
+    {
+        return true;
+    }
+
     Sint16 objPosX = objPos.x;
     Sint16 objPosY = objPos.y;
 
-
     // The most common case will be, that the object does not collide with the
     // playfield. So we check, if the object's surface only overlaps background
     // tiles. If yes, we can return false, without checking the pixel data
@@ -467,7 +475,7 @@ bool PlayGround::collidesWithParticle(const ParticleBase *particle) const
     const SDL_Rect &pos = particle->getPosition();
 
     return SDL_TOOLS::inside(pos.x, pos.y, m_boundingBox) ?
-        SDL_TOOLS::getPixel(getCollisionSurface(), pos.x, pos.y) != 0 : false;
+        SDL_TOOLS::getPixel(getCollisionSurface(), pos.x, pos.y) != 0 : true;
 }
 
 //----------------------------------------------------------------------------
@@ -595,6 +603,8 @@ void OverdrawObjectsConstVisitor::do_visit(const ParticleBase *p)
 
     const SDL_Rect &pos = p->getPosition();
 
+    assert(SDL_TOOLS::inside(pos.x, pos.y, m_mapSurface));
+
     Uint8 *mapPixel = (Uint8*)m_mapSurface->pixels
         + pos.y * m_mapSurface->pitch + pos.x * 4;
     Uint8 *shadowPixel = (Uint8*)m_shadowSurface->pixels
@@ -903,6 +913,16 @@ void CollisionDetectorVisitor::ProjectileCollisionDetectorVisitor::do_visit(Mort
     }
 }
 
+//----------------------------------------------------------------------------
+void CollisionDetectorVisitor::ProjectileCollisionDetectorVisitor::do_visit(SAMBatteryBase *s)
+{
+    if (ObjectBase::isCollision(m_projectile, s))
+    {
+        GameControlBase::getInstance()->onCollision(m_projectile, s);
+        setCollision();
+    }
+}
+
 //----------------------------------------------------------------------------
 void CollisionDetectorVisitor::ProjectileCollisionDetectorVisitor::do_visit(SwitchBase *s)
 {
@@ -1035,6 +1055,8 @@ void BlitObjectsVisitor::do_visit(ParticleBase *p)
     const SDL_Rect &pos = p->getPosition();
     const SDL_Surface *surface = p->getSurface();
 
+    assert(SDL_TOOLS::inside(pos.x, pos.y, m_shadowSurface));
+
     Uint8 *shadowPixel = (Uint8*)m_shadowSurface->pixels
         + pos.y * m_shadowSurface->pitch + pos.x * 4;
 
