@@ -7,7 +7,7 @@ PlayerStatus* PlayerStatus::sm_instance = NULL;
 //----------------------------------------------------------------------------
 PlayerStatus::PlayerStatus()
 {
-    m_score = 0;
+    m_score = 0.0;
     m_lifes = 5;
     m_bonus = 0;
 }
