@@ -7,7 +7,7 @@
 #define MENU_SINGLETON(t) \
   public: \
     virtual ~t##Menu(); \
-    static t##Menu* getInstance() throw(GuiMenuException){ \
+    static t##Menu* getInstance() { \
       if(sm_instance == NULL) \
         sm_instance = new t##Menu(); \
       return sm_instance; \
@@ -16,7 +16,7 @@
       ZAP_POINTER(sm_instance); \
     }\
   protected: \
-    t##Menu() throw(GuiMenuException); \
+    t##Menu(); \
     t##Menu(t##Menu &c); \
     static t##Menu *sm_instance
 
