@@ -120,7 +120,7 @@ void LevelSelectorMenu::initMissionSelect()
 PARAGUI_CALLBACK(LevelSelectorMenu::onMissionSelected)
 {
     PG_ListBoxItem *item = (PG_ListBoxItem*)data;
-    m_selectedIndex = (int)item->GetUserData();
+    m_selectedIndex = (long)item->GetUserData();
 
     PlayerConfiguration::getInstance()->getMission()
         ->updateLastPlayed(getCurrentlySelected(), 0);
