@@ -115,22 +115,27 @@ void StatusBarMenu::updateFuel()
         return;
     }
 
-    unsigned currentFuel = (unsigned)(((double)(ship->getFuel())) / 
-      GameControlBase::getInstance()->getPlayerFuel() * 100);
+    unsigned currentFuel = 100 * ship->getFuel() / ship->getFuelCapacity();
     if (currentFuel != m_lastFuelValue)
     {
-      m_lastFuelValue = currentFuel;
-      PG_Widget* fuelWidget = getWidget(ID_STATUSBAR_FUEL_ENTRY);
-      SDL_Color col = {0,0,0};
-      if(m_lastFuelValue > 50)
-        col.g = 255;
-      else if(m_lastFuelValue > 25)
-        col.r = 255, col.g = 200;
-      else
-        col.r = 255;
-       
-      fuelWidget->SetFontColor(col);
-      fuelWidget->SetTextFormat("%d%%", m_lastFuelValue);
-      fuelWidget->Redraw();
+        m_lastFuelValue = currentFuel;
+        PG_Widget* fuelWidget = getWidget(ID_STATUSBAR_FUEL_ENTRY);
+        SDL_Color col = {0,0,0};
+        if (m_lastFuelValue > 50)
+        {
+            col.g = 255;
+        }
+        else if (m_lastFuelValue > 25)
+        {
+            col.r = 255, col.g = 200;
+        }
+        else
+        {
+            col.r = 255;
+        }
+
+        fuelWidget->SetFontColor(col);
+        fuelWidget->SetTextFormat("%d%%", m_lastFuelValue);
+        fuelWidget->Redraw();
     }
 }
