@@ -19,6 +19,7 @@ class BlackHole : public StaticDecorationBase
     class InitializationData : public StaticDecorationBase::InitializationData
     {
       public:
+        InitializationData();
         InitializationData(const XMLNode *blackHoleNode);
         ~InitializationData();
 
@@ -27,8 +28,10 @@ class BlackHole : public StaticDecorationBase
 
 
     //------------------------------------------------------------------------
-    virtual ~BlackHole();
+    BlackHole(const InitializationData &init);
+    ~BlackHole();
 
+    //------------------------------------------------------------------------
     static BlackHole *create(const XMLNode *blackHoleNode);
 
     //------------------------------------------------------------------------
@@ -42,9 +45,8 @@ class BlackHole : public StaticDecorationBase
     //------------------------------------------------------------------------
     void update();
 
-  protected:
     //------------------------------------------------------------------------
-    BlackHole(const InitializationData &init);
+    void updateSurface();
 
   private:
     //------------------------------------------------------------------------
