@@ -21,6 +21,9 @@ class DecorationBase : public ObjectBase
 
         /// The object id of the decoration.
         unsigned id;
+
+        /// Indicates, if the decoration shall be initially hidden.
+        bool hidden;
     };
 
     //------------------------------------------------------------------------
