@@ -81,6 +81,7 @@ class Grinder : public MovingDecorationBase
     class InitializationData : public MovingDecorationBase::InitializationData
     {
       public:
+        InitializationData();
         InitializationData(const XMLNode *grinderNode);
         ~InitializationData();
 
@@ -88,22 +89,29 @@ class Grinder : public MovingDecorationBase
     };
 
     //------------------------------------------------------------------------
+    Grinder(const InitializationData &init);
     virtual ~Grinder();
 
-    static Grinder *create(const XMLNode *grinderNode);
+    //------------------------------------------------------------------------
+    inline unsigned getCurrentFrame() const
+    {
+        return m_currentFrame;
+    }
 
     //------------------------------------------------------------------------
     void update();
 
-  protected:
     //------------------------------------------------------------------------
-    Grinder(const InitializationData &init);
+    void updateSurface();
+
+    //------------------------------------------------------------------------
+    static Grinder *create(const XMLNode *grinderNode);
+
+  protected:
 
     //------------------------------------------------------------------------
     void initVelocity();
 
-    static Grinder *create(const InitializationData &init);
-
   private:
     //------------------------------------------------------------------------
     DECLARE_OBJECT_VISITOR_API();
