@@ -75,11 +75,12 @@ class MortarBarrel
         unsigned speed;
         unsigned delay;
         unsigned exploderDelay;
-        GrenadeBase::EnumWarheadStrategy grenadeWarheadStrategy;
+        Grenade::EnumWarheadStrategy grenadeWarheadStrategy;
     };
 
     ~MortarBarrel();
 
+    //------------------------------------------------------------------------
     inline int getAngle() const
     {
         return m_angle;
@@ -89,6 +90,7 @@ class MortarBarrel
         m_angle = SinusTable::normalize(angle);
     }
 
+    //------------------------------------------------------------------------
     inline unsigned getGrenadeSpeed() const
     {
         return m_grenadeSpeed;
@@ -99,34 +101,45 @@ class MortarBarrel
         return m_grenadeExploderDelay;
     }
 
-    inline GrenadeBase::EnumWarheadStrategy getGrenadeWarheadStrategy() const
+    inline Grenade::EnumWarheadStrategy getGrenadeWarheadStrategy() const
     {
         return m_grenadeWarheadStrategy;
     }
 
+    //------------------------------------------------------------------------
     void update(MortarBase *mortar);
 
+    //------------------------------------------------------------------------
     inline void setStrategy(UpdateStrategy *strategy)
     {
         m_strategy = strategy;
     }
 
+    //------------------------------------------------------------------------
     static MortarBarrel *create(const XMLNode *barrelNode);
 
+    //------------------------------------------------------------------------
+    Grenade *createGrenade(MortarBase *mortar) const;
+
   protected:
+
+    //------------------------------------------------------------------------
     MortarBarrel(const InitializationData &init);
 
+    //------------------------------------------------------------------------
     int m_angle;
     int m_angleStep;
 
     unsigned m_grenadeSpeed;
     unsigned m_grenadeExploderDelay;
-    GrenadeBase::EnumWarheadStrategy m_grenadeWarheadStrategy;
+    Grenade::EnumWarheadStrategy m_grenadeWarheadStrategy;
 
     unsigned m_frameDelay;
     unsigned m_frameCounter;
 
   private:
+
+    //------------------------------------------------------------------------
     UpdateStrategy *m_strategy;
 };
 
@@ -169,6 +182,7 @@ class MortarBase : public StaticDecorationBase,
           public OrientatingDecorationBase::InitializationData
     {
       public:
+        InitializationData();
         InitializationData(const XMLNode *mortarNode);
         ~InitializationData();
 
@@ -176,9 +190,9 @@ class MortarBase : public StaticDecorationBase,
     };
 
 
+    //------------------------------------------------------------------------
     virtual ~MortarBase();
 
-    static MortarBase *create(const XMLNode *mortarNode);
 
     /// Returns, whether the mortar can fire to the given angle.
     bool isAngleInRange(int angle) const;
@@ -200,12 +214,18 @@ class MortarBase : public StaticDecorationBase,
     //------------------------------------------------------------------------
     void update();
 
+    //------------------------------------------------------------------------
+    void updateSurface();
+
+    //------------------------------------------------------------------------
+    static MortarBase *create(const InitializationData &init);
+    static MortarBase *create(const XMLNode *mortarNode);
+
   protected:
     //------------------------------------------------------------------------
     MortarBase(const InitializationData &init);
 
-    static MortarBase *create(const InitializationData &init);
-
+    //------------------------------------------------------------------------
     Uint16 m_tipOffset;
 
   private:
@@ -223,9 +243,11 @@ class MortarBase : public StaticDecorationBase,
 class TopMortar : public MortarBase
 {
   public:
+    //------------------------------------------------------------------------
     TopMortar(const InitializationData &init);
     ~TopMortar();
 
+    //------------------------------------------------------------------------
     int getCenterAngle() const;
     OrientatingDecorationBase::Orientation getTipPosition(
         Sint16 &x, Sint16 &y) const;
@@ -235,9 +257,11 @@ class TopMortar : public MortarBase
 class BottomMortar : public MortarBase
 {
   public:
+    //------------------------------------------------------------------------
     BottomMortar(const InitializationData &init);
     ~BottomMortar();
 
+    //------------------------------------------------------------------------
     int getCenterAngle() const;
     OrientatingDecorationBase::Orientation getTipPosition(
         Sint16 &x, Sint16 &y) const;
@@ -247,9 +271,11 @@ class BottomMortar : public MortarBase
 class LeftMortar : public MortarBase
 {
   public:
+    //------------------------------------------------------------------------
     LeftMortar(const InitializationData &init);
     ~LeftMortar();
 
+    //------------------------------------------------------------------------
     int getCenterAngle() const;
     OrientatingDecorationBase::Orientation getTipPosition(
         Sint16 &x, Sint16 &y) const;
@@ -259,9 +285,11 @@ class LeftMortar : public MortarBase
 class RightMortar : public MortarBase
 {
   public:
+    //------------------------------------------------------------------------
     RightMortar(const InitializationData &init);
     ~RightMortar();
 
+    //------------------------------------------------------------------------
     int getCenterAngle() const;
     OrientatingDecorationBase::Orientation getTipPosition(
         Sint16 &x, Sint16 &y) const;
