@@ -156,10 +156,17 @@ class ObjectBase
 
     //------------------------------------------------------------------------
     /**
-     * Called by the PlayGround to update this object.
+     * Called by the PlayGround to update the inner state of this object.
      */
     virtual void update() = 0;
 
+    //------------------------------------------------------------------------
+    /**
+     * Called by the PlayGround to update m_surface
+     * depending on the inner state of this object.
+     */
+    virtual void updateSurface() = 0;
+
     //------------------------------------------------------------------------
     /**
      * Called by the PlayGround to blit this object to the given surface.
