@@ -7,7 +7,7 @@ class ObjectBase;
 class Barrier;
 class BlackHole;
 class Crate;
-class GrenadeBase;
+class Grenade;
 class Grinder;
 class MagnetBase;
 class MortarBase;
@@ -26,6 +26,7 @@ class   TurretProjectile;
 class SAMBatteryBase;
 class SwitchBase;
 class Tank;
+class Thorn;
 class TurretBase;
 class ControllableObjectBase;
 class   Missile;
