@@ -9,15 +9,13 @@
  */
 class ObjectVisitor
 {
-    friend class ObjectRepository;
-
   public:
     virtual ~ObjectVisitor() = 0;
 
     inline void visit(Barrier *b) { do_visit(b); }
     inline void visit(BlackHole *b) { do_visit(b); }
     inline void visit(Crate *c) { do_visit(c); }
-    inline void visit(GrenadeBase *g) { do_visit(g); }
+    inline void visit(Grenade *g) { do_visit(g); }
     inline void visit(Grinder *g) { do_visit(g); }
     inline void visit(MagnetBase *m) { do_visit(m); }
     inline void visit(Missile *m) { do_visit(m); }
@@ -30,8 +28,16 @@ class ObjectVisitor
     inline void visit(Ship *s) { do_visit(s); }
     inline void visit(SwitchBase *s) { do_visit(s); }
     inline void visit(Tank *t) { do_visit(t); }
+    inline void visit(Thorn *t) { do_visit(t); }
     inline void visit(TurretBase *t) { do_visit(t); }
 
+    /**
+     * Called from ObjectRepository::acceptObjects().
+     *
+     * @return false, to abort the for loop in the ObjectRepository.
+     */
+    virtual bool continueForLoopInVisitObjectList() const { return true; }
+
   protected:
     ObjectVisitor() {}
 
@@ -39,7 +45,7 @@ class ObjectVisitor
     virtual void do_visit(Barrier *b) {}
     virtual void do_visit(BlackHole *b) {}
     virtual void do_visit(Crate *c) {}
-    virtual void do_visit(GrenadeBase *g) {}
+    virtual void do_visit(Grenade *g) {}
     virtual void do_visit(Grinder *g) {}
     virtual void do_visit(MagnetBase *m) {}
     virtual void do_visit(Missile *m) {}
@@ -52,14 +58,8 @@ class ObjectVisitor
     virtual void do_visit(Ship *s) {}
     virtual void do_visit(SwitchBase *s) {}
     virtual void do_visit(Tank *t) {}
+    virtual void do_visit(Thorn *t) {}
     virtual void do_visit(TurretBase *t) {}
-
-    /**
-     * Called from ObjectRepository::acceptObjects().
-     *
-     * @return false, to abort the for loop in the ObjectRepository.
-     */
-    virtual bool continueForLoopInVisitObjectList() const { return true; }
 };
 
 
@@ -69,15 +69,13 @@ class ObjectVisitor
  */
 class ObjectConstVisitor
 {
-    friend class ObjectRepository;
-
   public:
     virtual ~ObjectConstVisitor() = 0;
 
     inline void visit(const Barrier *b) { do_visit(b); }
     inline void visit(const BlackHole *b) { do_visit(b); }
     inline void visit(const Crate *c) { do_visit(c); }
-    inline void visit(const GrenadeBase *g) { do_visit(g); }
+    inline void visit(const Grenade *g) { do_visit(g); }
     inline void visit(const Grinder *g) { do_visit(g); }
     inline void visit(const MagnetBase *m) { do_visit(m); }
     inline void visit(const Missile *m) { do_visit(m); }
@@ -90,8 +88,16 @@ class ObjectConstVisitor
     inline void visit(const Ship *s) { do_visit(s); }
     inline void visit(const SwitchBase *s) { do_visit(s); }
     inline void visit(const Tank *t) { do_visit(t); }
+    inline void visit(const Thorn *t) { do_visit(t); }
     inline void visit(const TurretBase *t) { do_visit(t); }
 
+    /**
+     * Called from ObjectRepository::acceptObjects().
+     *
+     * @return false, to abort the for loop in the ObjectRepository.
+     */
+    virtual bool continueForLoopInVisitObjectList() const { return true; }
+
   protected:
     ObjectConstVisitor() {}
 
@@ -99,7 +105,7 @@ class ObjectConstVisitor
     virtual void do_visit(const Barrier *b) {}
     virtual void do_visit(const BlackHole *b) {}
     virtual void do_visit(const Crate *c) {}
-    virtual void do_visit(const GrenadeBase *g) {}
+    virtual void do_visit(const Grenade *g) {}
     virtual void do_visit(const Grinder *g) {}
     virtual void do_visit(const MagnetBase *m) {}
     virtual void do_visit(const Missile *m) {}
@@ -112,14 +118,8 @@ class ObjectConstVisitor
     virtual void do_visit(const Ship *s) {}
     virtual void do_visit(const SwitchBase *s) {}
     virtual void do_visit(const Tank *t) {}
+    virtual void do_visit(const Thorn *t) {}
     virtual void do_visit(const TurretBase *t) {}
-
-    /**
-     * Called from ObjectRepository::acceptObjects().
-     *
-     * @return false, to abort the for loop in the ObjectRepository.
-     */
-    virtual bool continueForLoopInVisitObjectList() const { return true; }
 };
 
 
@@ -204,7 +204,7 @@ class CreateExplosionParticleConstVisitor : public ObjectConstVisitor
 
   private:
     //------------------------------------------------------------------------
-    void do_visit(const GrenadeBase *g);
+    void do_visit(const Grenade *g);
     void do_visit(const Missile *m);
     void do_visit(const MortarBase *m);
     void do_visit(const ProjectileBase *p);
@@ -227,8 +227,6 @@ class CreateExplosionParticleConstVisitor : public ObjectConstVisitor
  * for a single object, that is about to explode.
  * Depending on the type of object,
  * the particle will be initialized in a different way.
- *
- * @todo Finish this visitor and make use of it.
  */
 class InitializeExplosionParticleConstVisitor : public ObjectConstVisitor
 {
@@ -240,7 +238,7 @@ class InitializeExplosionParticleConstVisitor : public ObjectConstVisitor
 
   private:
     //------------------------------------------------------------------------
-    void do_visit(const GrenadeBase *g);
+    void do_visit(const Grenade *g);
     void do_visit(const Missile *m);
     void do_visit(const MortarBase *m);
     void do_visit(const ProjectileBase *p);
