@@ -89,6 +89,7 @@ class Tank : public MovingDecorationBase
     class InitializationData : public MovingDecorationBase::InitializationData
     {
       public:
+        InitializationData();
         InitializationData(const XMLNode *tankNode);
         ~InitializationData();
 
@@ -102,10 +103,9 @@ class Tank : public MovingDecorationBase
     };
 
     //------------------------------------------------------------------------
+    Tank(const InitializationData &init);
     ~Tank();
 
-    static Tank *create(const XMLNode *tankNode);
-
     //------------------------------------------------------------------------
     /**
      * Called for a projectile collision to determine,
@@ -136,12 +136,13 @@ class Tank : public MovingDecorationBase
     //------------------------------------------------------------------------
     void update();
 
-  protected:
     //------------------------------------------------------------------------
-    Tank(const InitializationData &init);
+    void updateSurface();
 
-    static Tank *create(const InitializationData &init);
+    //------------------------------------------------------------------------
+    static Tank *create(const XMLNode *tankNode);
 
+  protected:
     //------------------------------------------------------------------------
     void initMoving();
     void initWaitForShooting();
