@@ -49,6 +49,7 @@ ObjectBase::~ObjectBase()
 DecorationBase::InitializationData::InitializationData()
 {
     id = 0;
+    hidden = false;
 }
 
 //----------------------------------------------------------------------------
@@ -60,6 +61,8 @@ DecorationBase::InitializationData::InitializationData(const XMLNode *node)
         throw XMLException(
             "The value of the 'id' must not be greater or equal than 1024");
     }
+
+    hidden = node->getBoolProperty("hide", false);
 }
 
 //----------------------------------------------------------------------------
@@ -72,6 +75,7 @@ DecorationBase::InitializationData::~InitializationData()
 DecorationBase::DecorationBase(const InitializationData &init)
         : ObjectBase(init.id)
 {
+    setHidden(init.hidden);
 }
 
 //----------------------------------------------------------------------------
@@ -213,6 +217,9 @@ AnimatedDecorationBase::InitializationData::InitializationData()
     on = 0;
     off = 0;
     delay = 0;
+
+    activatedPresent = false;
+    activated = false;
 }
 
 //----------------------------------------------------------------------------
@@ -221,6 +228,9 @@ AnimatedDecorationBase::InitializationData::InitializationData(const XMLNode *no
     on = node->getUnsignedProperty("on", 0);
     off = node->getUnsignedProperty("off", 0);
     delay = node->getUnsignedProperty("delay", 0);
+
+    activatedPresent = node->hasProperty("activated");
+    activated = node->getBoolProperty("activated", false);
 }
 
 //----------------------------------------------------------------------------
@@ -233,9 +243,21 @@ AnimatedDecorationBase::InitializationData::~InitializationData()
 AnimatedDecorationBase::AnimatedDecorationBase(
     const InitializationData &init)
 {
-    m_onInterval = init.on * SDLFrameRate::getFrameRate();
-    m_offInterval = init.off * SDLFrameRate::getFrameRate();
-    m_initialDelay = init.delay * SDLFrameRate::getFrameRate();
+    m_activatedPresent = init.activatedPresent;
+    m_activated = init.activated;
+
+    if (m_activatedPresent)
+    {
+        m_onInterval = 0;
+        m_offInterval = 0;
+        m_initialDelay = 0;
+    }
+    else
+    {
+        m_onInterval = init.on * SDLFrameRate::getFrameRate();
+        m_offInterval = init.off * SDLFrameRate::getFrameRate();
+        m_initialDelay = init.delay * SDLFrameRate::getFrameRate();
+    }
 }
 
 //----------------------------------------------------------------------------
@@ -394,8 +416,6 @@ MovingDecorationBase::~MovingDecorationBase()
 //----------------------------------------------------------------------------
 Barrier::InitializationData::InitializationData()
 {
-    activatedPresent = false;
-    activated = false;
 }
 
 //----------------------------------------------------------------------------
@@ -404,8 +424,6 @@ Barrier::InitializationData::InitializationData(const XMLNode *barrierNode)
           AnimatedDecorationBase::InitializationData(barrierNode),
           HVDecorationBase::InitializationData(barrierNode)
 {
-    activatedPresent = barrierNode->hasProperty("activated");
-    activated = barrierNode->getBoolProperty("activated", false);
 }
 
 //----------------------------------------------------------------------------
@@ -528,13 +546,10 @@ Barrier::Barrier(const InitializationData &init)
           AnimatedDecorationBase(init),
           HVDecorationBase(init)
 {
-    m_activated = false;
-
     m_frameCounter = 0;
 
     if (init.activatedPresent)
     {
-        m_activated = init.activated;
         setUpdateState(DoNothing::getInstance());
     }
     else
@@ -565,7 +580,7 @@ void Barrier::update()
 void Barrier::updateSurface()
 {
     setSurface(BarrierSurfaces::getInstance()->getSurface(
-                   getOrientation(), m_activated, getSize()));
+                   getOrientation(), isActivated(), getSize()));
 }
 
 //----------------------------------------------------------------------------
@@ -676,7 +691,6 @@ DECLARE_OBJECT_VISITOR_API_BODY(BlackHole)
 //----------------------------------------------------------------------------
 Crate::InitializationData::InitializationData()
 {
-    hidden = false;
     type = CrateSurfaces::T_SMALL;
     score = 0;
     amount = 0;
@@ -686,8 +700,6 @@ Crate::InitializationData::InitializationData()
 Crate::InitializationData::InitializationData(const XMLNode *crateNode)
         : StaticDecorationBase::InitializationData(crateNode)
 {
-    hidden = crateNode->getBoolProperty("hide", false);
-
     const std::string &prop = crateNode->getStringProperty("type");
     if (prop == "small")  type = CrateSurfaces::T_SMALL;
     else if (prop == "medium")  type = CrateSurfaces::T_MEDIUM;
@@ -712,8 +724,6 @@ Crate::InitializationData::~InitializationData()
 Crate::Crate(const InitializationData &init)
         : StaticDecorationBase(init)
 {
-    setHidden(init.hidden);
-
     m_type = init.type;
     switch (m_type)
     {
@@ -812,33 +822,53 @@ MagnetBase::InitializationData::~InitializationData()
 //----------------------------------------------------------------------------
 MagnetBase::Initial MagnetBase::Initial::sm_instance;
 MagnetBase::InitialDelay MagnetBase::InitialDelay::sm_instance;
-MagnetBase::PermanentActivation MagnetBase::PermanentActivation::sm_instance;
 MagnetBase::Activated MagnetBase::Activated::sm_instance;
 MagnetBase::Deactivated MagnetBase::Deactivated::sm_instance;
 
+//----------------------------------------------------------------------------
+void MagnetBase::Initial::onEntry(MagnetBase *magnet)
+{
+}
+
 //----------------------------------------------------------------------------
 void MagnetBase::Initial::update(MagnetBase *magnet)
 {
     UpdateState *state = NULL;
-    if (magnet->getInitialDelay() > 0)
+    if (magnet->isActivatedPresent())
     {
-        state = InitialDelay::getInstance();
-    }
-    else if (magnet->getOnInterval() == 0 || magnet->getOffInterval() == 0)
-    {
-        magnet->addGravityToPlayGround();
-        state = PermanentActivation::getInstance();
+        if (magnet->isActivated())
+        {
+            magnet->addGravityToPlayGround();
+            state = Activated::getInstance();
+        }
+        else
+        {
+            state = Deactivated::getInstance();
+        }
     }
     else
     {
-        magnet->addGravityToPlayGround();
-        state = Activated::getInstance();
+        if (magnet->getInitialDelay() > 0)
+        {
+            state = InitialDelay::getInstance();
+        }
+        else
+        {
+            magnet->addGravityToPlayGround();
+            state = Activated::getInstance();
+        }
     }
 
     magnet->setUpdateState(state);
     state->update(magnet);
 }
 
+
+//----------------------------------------------------------------------------
+void MagnetBase::InitialDelay::onEntry(MagnetBase *magnet)
+{
+}
+
 //----------------------------------------------------------------------------
 void MagnetBase::InitialDelay::update(MagnetBase *magnet)
 {
@@ -850,22 +880,32 @@ void MagnetBase::InitialDelay::update(MagnetBase *magnet)
     }
 }
 
+
 //----------------------------------------------------------------------------
-void MagnetBase::PermanentActivation::update(MagnetBase *magnet)
+void MagnetBase::Activated::onEntry(MagnetBase *magnet)
+{
+}
+
+//----------------------------------------------------------------------------
+void MagnetBase::Activated::update(MagnetBase *magnet)
 {
     if (++magnet->m_frameDelay == SDLFrameRate::getFrameRate() / 12)
     {
         magnet->m_frameDelay = 0;
         magnet->m_currentFrame = (magnet->m_currentFrame+1) % 4;
     }
-}
 
-//----------------------------------------------------------------------------
-void MagnetBase::Activated::update(MagnetBase *magnet)
-{
-    PermanentActivation::getInstance()->update(magnet);
+    bool switchToDeactivated = false;
+    if (magnet->getOnInterval() > 0 && magnet->getOffInterval() > 0)
+    {
+        if (++magnet->m_frameCounter == magnet->getOnInterval())
+        {
+            switchToDeactivated = true;
+        }
+    }
 
-    if (++magnet->m_frameCounter == magnet->getOnInterval())
+    if (switchToDeactivated ||
+        (magnet->isActivatedPresent() && !magnet->isActivated()))
     {
         magnet->m_frameCounter = 0;
         magnet->subGravityFromPlayGround();
@@ -873,10 +913,26 @@ void MagnetBase::Activated::update(MagnetBase *magnet)
     }
 }
 
+
+//----------------------------------------------------------------------------
+void MagnetBase::Deactivated::onEntry(MagnetBase *magnet)
+{
+}
+
 //----------------------------------------------------------------------------
 void MagnetBase::Deactivated::update(MagnetBase *magnet)
 {
-    if (++magnet->m_frameCounter == magnet->getOffInterval())
+    bool switchToActivated = false;
+    if (magnet->getOnInterval() > 0 && magnet->getOffInterval() > 0)
+    {
+        if (++magnet->m_frameCounter == magnet->getOffInterval())
+        {
+            switchToActivated = true;
+        }
+    }
+
+    if (switchToActivated ||
+        (magnet->isActivatedPresent() && magnet->isActivated()))
     {
         magnet->m_frameCounter = 0;
         magnet->addGravityToPlayGround();
@@ -1341,6 +1397,9 @@ Platform::InitializationData::InitializationData(const XMLNode *platformNode)
 
     left = getEdgeType(platformNode, "left");
     right = getEdgeType(platformNode, "right");
+
+    fuel = platformNode->getBoolProperty("fuel", false);
+    fuelCost = platformNode->getUnsignedProperty("fuel_cost", 20);
 }
 
 //----------------------------------------------------------------------------
@@ -1387,8 +1446,10 @@ Platform::Platform(const InitializationData &init)
 
     m_left = init.left;
     m_right = init.right;
-    m_fuel = (m_left == PlatformSurfaces::ET_FUEL ||
-              m_right == PlatformSurfaces::ET_FUEL);
+    m_fuel = init.fuel ||
+        (m_left == PlatformSurfaces::ET_FUEL) ||
+        (m_right == PlatformSurfaces::ET_FUEL);
+    m_fuelCost = init.fuelCost;
 
     initLandingZone();
 
@@ -1449,6 +1510,7 @@ DECLARE_OBJECT_VISITOR_API_BODY(Platform)
 //----------------------------------------------------------------------------
 SAMBatteryBase::InitializationData::InitializationData()
 {
+    hitPoints = 0;
     delay = 0;
     missileFuel = 0;
     missileHeadingStrategy = Missile::HS_DIRECT;
@@ -1460,6 +1522,8 @@ SAMBatteryBase::InitializationData::InitializationData(const XMLNode *samNode)
         : StaticDecorationBase::InitializationData(samNode),
           OrientatingDecorationBase::InitializationData(samNode)
 {
+    hitPoints = samNode->getUnsignedProperty("hitpoints", 10);
+
     delay = samNode->getUnsignedProperty("delay", 5);
 
     missileFuel = samNode->getUnsignedProperty("fuel", 5);
@@ -1498,6 +1562,8 @@ SAMBatteryBase::SAMBatteryBase(const InitializationData &init)
         : StaticDecorationBase(init),
           OrientatingDecorationBase(init)
 {
+    m_hitPoints = init.hitPoints;
+
     m_frameDelay = init.delay * SDLFrameRate::getFrameRate();
     m_frameCounter = 0;
 
@@ -1562,9 +1628,9 @@ Missile *SAMBatteryBase::do_createMissile(Sint16 angle) const
 {
     Missile *m = new Missile(m_missileHeadingStrategy,
                              m_missileWarheadStrategy,
+                             m_missileFuel,
                              getId());
     do_setInitialMissilePosition(m);
-    m->setFuel(m_missileFuel);
     m->setAngle(angle);
 
     return m;
@@ -1594,6 +1660,7 @@ Missile *TopSAMBattery::createMissile() const
 //----------------------------------------------------------------------------
 void TopSAMBattery::do_setInitialMissilePosition(Missile *m) const
 {
+    // @todo: Don't access the w and h fields of getPosition().
     m->setPosition(
         getPosition().x - (m->getPosition().w - getPosition().w) / 2,
         getPosition().y + 4);
@@ -1620,6 +1687,7 @@ Missile *BottomSAMBattery::createMissile() const
 //----------------------------------------------------------------------------
 void BottomSAMBattery::do_setInitialMissilePosition(Missile *m) const
 {
+    // @todo: Don't access the w and h fields of getPosition().
     m->setPosition(
         getPosition().x - (m->getPosition().w - getPosition().w) / 2,
         getPosition().y - 4);
@@ -1646,6 +1714,7 @@ Missile *LeftSAMBattery::createMissile() const
 //----------------------------------------------------------------------------
 void LeftSAMBattery::do_setInitialMissilePosition(Missile *m) const
 {
+    // @todo: Don't access the w and h fields of getPosition().
     m->setPosition(
         getPosition().x + 4,
         getPosition().y - (m->getPosition().h - getPosition().h) / 2);
@@ -1672,6 +1741,7 @@ Missile *RightSAMBattery::createMissile() const
 //----------------------------------------------------------------------------
 void RightSAMBattery::do_setInitialMissilePosition(Missile *m) const
 {
+    // @todo: Don't access the w and h fields of getPosition().
     m->setPosition(
         getPosition().x - 4,
         getPosition().y - (m->getPosition().h - getPosition().h) / 2);
@@ -1746,9 +1816,11 @@ void SwitchBase::toggle()
 {
     for (size_t i=0; i<m_objectIds.size(); i++)
     {
-        Barrier *barrier = dynamic_cast<Barrier*>(
-            ObjectRepository::getInstance()->getObject(m_objectIds[i]));
-        if (barrier)  barrier->toggle();
+        AnimatedDecorationBase *object =
+            dynamic_cast<AnimatedDecorationBase*>(
+                ObjectRepository::getInstance()->getObject(m_objectIds[i]));
+
+        if (object)  object->toggle();
     }
 }
 
@@ -2318,8 +2390,11 @@ int TopTurret::getCenterAngle() const
 OrientatingDecorationBase::Orientation TopTurret::getTipPosition(
     Sint16 &x, Sint16 &y) const
 {
-    x = getPosition().x + getPosition().w/2;
-    y = getPosition().y + getPosition().h - m_tipOffset;
+    Uint16 w, h;
+    TurretSurfaces::getInstance()->getTurretSize(getType(), w, h);
+
+    x = getPosition().x + w/2;
+    y = getPosition().y + h - m_tipOffset;
     return O_TOP;
 }
 
@@ -2345,7 +2420,10 @@ int BottomTurret::getCenterAngle() const
 OrientatingDecorationBase::Orientation BottomTurret::getTipPosition(
     Sint16 &x, Sint16 &y) const
 {
-    x = getPosition().x + getPosition().w/2;
+    Uint16 w, h;
+    TurretSurfaces::getInstance()->getTurretSize(getType(), w, h);
+
+    x = getPosition().x + w/2;
     y = getPosition().y + m_tipOffset - 1;
     return O_BOTTOM;
 }
@@ -2372,8 +2450,11 @@ int LeftTurret::getCenterAngle() const
 OrientatingDecorationBase::Orientation LeftTurret::getTipPosition(
     Sint16 &x, Sint16 &y) const
 {
-    x = getPosition().x + getPosition().w - m_tipOffset;
-    y = getPosition().y + getPosition().h/2;
+    Uint16 w, h;
+    TurretSurfaces::getInstance()->getTurretSize(getType(), w, h);
+
+    x = getPosition().x + w - m_tipOffset;
+    y = getPosition().y + h/2;
     return O_LEFT;
 }
 
@@ -2399,8 +2480,11 @@ int RightTurret::getCenterAngle() const
 OrientatingDecorationBase::Orientation RightTurret::getTipPosition(
     Sint16 &x, Sint16 &y) const
 {
+    Uint16 w, h;
+    TurretSurfaces::getInstance()->getTurretSize(getType(), w, h);
+
     x = getPosition().x + m_tipOffset - 1;
-    y = getPosition().y + getPosition().h/2;
+    y = getPosition().y + h/2;
     return O_RIGHT;
 }
 
@@ -2549,23 +2633,26 @@ Grenade *MortarBarrel::createGrenade(MortarBase *mortar) const
     Grenade *grenade =
         new Grenade(getGrenadeWarheadStrategy(), mortar->getId());
 
+    Uint16 gw, gh;
+    GrenadeSurfaces::getInstance()->getGrenadeSize(gw, gh);
+
     // Set the initial position.
     Sint16 x, y;
     switch (mortar->getTipPosition(x, y))
     {
     case OrientatingDecorationBase::O_TOP:
-        x -= grenade->getPosition().w / 2;
+        x -= gw / 2;
         break;
     case OrientatingDecorationBase::O_BOTTOM:
-        x -= grenade->getPosition().w / 2;
-        y -= grenade->getPosition().h;
+        x -= gw / 2;
+        y -= gh;
         break;
     case OrientatingDecorationBase::O_LEFT:
-        y -= grenade->getPosition().h / 2;
+        y -= gh / 2;
         break;
     case OrientatingDecorationBase::O_RIGHT:
-        x -= grenade->getPosition().w;
-        y -= grenade->getPosition().h / 2;
+        x -= gw;
+        y -= gh / 2;
         break;
     }
 
