@@ -40,6 +40,7 @@ ControllableObjectBase::ControllableObjectBase(const unsigned creatorId)
     m_angle = SURFACES_ROTATION_STEPS / 2;
     m_fineAngle = 180.0;
     m_rotation = ROT_NONE;
+    m_fuelCapacity = 0;
     m_fuel = 0;
     m_thrust = false;
     m_explode = false;
@@ -86,6 +87,30 @@ void ControllableObjectBase::initBottomPixels()
     m_bottomPixels.h = 1;
 }
 
+
+//----------------------------------------------------------------------------
+void ControllableObjectBase::addFuel(unsigned increment)
+{
+    m_fuel += increment;
+    if (m_fuel > m_fuelCapacity)
+    {
+        m_fuel = m_fuelCapacity;
+    }
+}
+
+//----------------------------------------------------------------------------
+bool ControllableObjectBase::decFuel(unsigned decrement)
+{
+    if (m_fuel < decrement)
+    {
+        m_fuel = 0;
+        return true;
+    }
+
+    m_fuel -= decrement;
+    return false;
+}
+
 //----------------------------------------------------------------------------
 void ControllableObjectBase::setThrust(bool enable)
 {
@@ -247,7 +272,7 @@ Sint16 Missile::SmartHeadingStrategy::calculateHeadingAngle(
     Sint16 a, Sint16 angle, Sint16 gx, Sint16 gy) const
 {
     // Calculate the rotation such way, that it flies directly
-    // to the player's ship, while compensating gravity.
+    // to the player's ship, while compensating gavity.
 
     double ax = a * SinusTable::sin(angle);
     double ay = a * SinusTable::cos(angle);
@@ -393,9 +418,13 @@ void Missile::StarBurstWarheadStrategy::onCreateExplosionParticles(const Missile
 //----------------------------------------------------------------------------
 Missile::Missile(EnumHeadingStrategy heading,
                  EnumWarheadStrategy warhead,
+                 const unsigned fuel,
                  const unsigned creatorId)
         : ControllableObjectBase(creatorId)
 {
+    setFuelCapacity(fuel);
+    setFuel(fuel);
+
     m_mass = 20;
     m_thrust = true;
 
@@ -576,6 +605,9 @@ void Ship::Flying::update(Ship *s)
 //----------------------------------------------------------------------------
 Ship::Ship(ShipSurfaces::Ship shipType) : ControllableObjectBase(0)
 {
+    // 100 seconds of fuel.
+    setFuelCapacity(100 * SDLFrameRate::getFrameRate());
+
     m_shipType = shipType;
     m_mass = 100;
     m_fire = false;
@@ -612,29 +644,6 @@ Ship::~Ship()
 }
 
 
-//----------------------------------------------------------------------------
-void Ship::incFuel(unsigned increment, unsigned maximum)
-{
-    m_fuel += increment;
-    if (m_fuel > maximum)
-    {
-        m_fuel = maximum;
-    }
-}
-
-//----------------------------------------------------------------------------
-bool Ship::decFuel(unsigned decrement)
-{
-    if (m_fuel < decrement)
-    {
-        m_fuel = 0;
-        return true;
-    }
-
-    m_fuel -= decrement;
-    return false;
-}
-
 //----------------------------------------------------------------------------
 bool Ship::hasCapacity(const Crate *crate) const
 {
@@ -996,16 +1005,18 @@ ShipProjectile::ShipProjectile(const Ship *shooter)
     Sint16 xm, ym;
     SDL_TOOLS::getCentre(shipPosition, xm, ym);
 
+    Uint16 pw, ph;
+    ProjectileSurfaces::getInstance()->getProjectileSize(pw, ph);
+
     // When rotating, the tip of the ship moves in a circle with a radius,
     // we are calculating here.
     // To keep sure, the projectile won't touch the ship initially,
     // we add the height of the projectile's surface.
-    Uint16 r =
-        ym - (shipPosition.y + shooter->getTipOffset()) + getPosition().h;
+    Uint16 r = ym - (shipPosition.y + shooter->getTipOffset()) + ph;
 
     setPosition(
-        (Uint16)(xm - getPosition().w/2 + r*SinusTable::sin(shooter->getAngle())),
-        (Uint16)(ym - getPosition().h/2 + r*SinusTable::cos(shooter->getAngle())));
+        (Uint16)(xm - pw/2 + r*SinusTable::sin(shooter->getAngle())),
+        (Uint16)(ym - ph/2 + r*SinusTable::cos(shooter->getAngle())));
 
     // Calculate the projectile's velocity.
     MATH_TOOLS::Vector relativeVelocity;
@@ -1027,26 +1038,29 @@ TurretProjectile::TurretProjectile(const TurretBase *turret,
                                    const TurretBarrel *barrel)
         : ProjectileBase(turret->getId())
 {
+    Uint16 pw, ph;
+    ProjectileSurfaces::getInstance()->getProjectileSize(pw, ph);
+
     // Set the initial position.
     Sint16 x, y;
     switch (turret->getTipPosition(x, y))
     {
     case OrientatingDecorationBase::O_TOP:
-        x -= getPosition().w / 2;
+        x -= pw / 2;
         break;
 
     case OrientatingDecorationBase::O_BOTTOM:
-        x -= getPosition().w / 2;
-        y -= getPosition().h;
+        x -= pw / 2;
+        y -= ph;
         break;
 
     case OrientatingDecorationBase::O_LEFT:
-        y -= getPosition().h / 2;
+        y -= ph / 2;
         break;
 
     case OrientatingDecorationBase::O_RIGHT:
-        x -= getPosition().w;
-        y -= getPosition().h / 2;
+        x -= pw;
+        y -= ph / 2;
         break;
     }
 
@@ -1068,18 +1082,20 @@ TurretProjectile::~TurretProjectile()
 MissileProjectile::MissileProjectile(const Missile *missile, int angle)
         : ProjectileBase(missile->getCreatorId())
 {
+    Uint16 pw, ph;
+    ProjectileSurfaces::getInstance()->getProjectileSize(pw, ph);
+
     // Set the initial position.
     Sint16 x, y;
     SDL_TOOLS::getCentre(missile->getPosition(), x, y);
-    x -= getPosition().w / 2;
-    y -= getPosition().h / 2;
+    x -= pw / 2;
+    y -= ph / 2;
 
     setPosition(x, y);
 
     // Calculate the projectile's velocity.
     MATH_TOOLS::Vector relativeVelocity;
-    relativeVelocity.setExponential(
-        0.25 * PROJECTILE_VELOCITY, 1.0 * angle);
+    relativeVelocity.setExponential(0.25 * PROJECTILE_VELOCITY, 1.0 * angle);
 
     // Add the missile's current velocity to the projectile's velocity.
     getFineVelocity() = missile->getFineVelocity() + relativeVelocity;
@@ -1095,11 +1111,14 @@ MissileProjectile::~MissileProjectile()
 TankProjectile::TankProjectile(const Tank *tank)
         : ProjectileBase(tank->getId())
 {
+    Uint16 pw, ph;
+    ProjectileSurfaces::getInstance()->getProjectileSize(pw, ph);
+
     // Set the initial position.
     Sint16 x, y;
     SDL_TOOLS::getCentre(tank->getPosition(), x, y);
-    x -= getPosition().w / 2;
-    y -= getPosition().h / 2 + 2;
+    x -= pw / 2;
+    y -= ph / 2 + 2;
 
     x += (Sint16)trunc(9 * SinusTable::sin(tank->getAngle()));
     y += (Sint16)trunc(5 * SinusTable::cos(tank->getAngle()));
@@ -1121,18 +1140,20 @@ TankProjectile::~TankProjectile()
 GrenadeProjectile::GrenadeProjectile(const Grenade *grenade, int angle)
         : ProjectileBase(grenade->getCreatorId())
 {
+    Uint16 pw, ph;
+    ProjectileSurfaces::getInstance()->getProjectileSize(pw, ph);
+
     // Set the initial position.
     Sint16 x, y;
     SDL_TOOLS::getCentre(grenade->getPosition(), x, y);
-    x -= getPosition().w / 2;
-    y -= getPosition().h / 2;
+    x -= pw / 2;
+    y -= ph / 2;
 
     setPosition(x, y);
 
     // Calculate the projectile's velocity.
     MATH_TOOLS::Vector relativeVelocity;
-    relativeVelocity.setExponential(
-        0.25 * PROJECTILE_VELOCITY, 1.0 * angle);
+    relativeVelocity.setExponential(0.25 * PROJECTILE_VELOCITY, 1.0 * angle);
 
     // Add the grenade's current velocity to the projectile's velocity.
     getFineVelocity() = grenade->getFineVelocity() + relativeVelocity;
