@@ -1077,6 +1077,13 @@ void ProjectileSurfaces::destroy()
     ZAP_POINTER(sm_instance);
 }
 
+//----------------------------------------------------------------------------
+void ProjectileSurfaces::getProjectileSize(Uint16 &w, Uint16 &h) const
+{
+    w = getSurface()->w;
+    h = getSurface()->h;
+}
+
 
 
 //============================================================================
@@ -1114,6 +1121,13 @@ void GrenadeSurfaces::destroy()
     ZAP_POINTER(sm_instance);
 }
 
+//----------------------------------------------------------------------------
+void GrenadeSurfaces::getGrenadeSize(Uint16 &w, Uint16 &h) const
+{
+    w = getSurface()->w;
+    h = getSurface()->h;
+}
+
 
 
 //============================================================================
@@ -1504,6 +1518,16 @@ void TurretSurfaces::destroy()
     ZAP_POINTER(sm_instance);
 }
 
+//----------------------------------------------------------------------------
+void TurretSurfaces::getTurretSize(const Turret turret, Uint16 &w, Uint16 &h) const
+{
+    assert(turret >= 0);
+    assert(turret < T_TOTAL_NUMBER);
+
+    w = m_turrets[OrientatingDecorationBase::O_BOTTOM][turret]->w;
+    h = m_turrets[OrientatingDecorationBase::O_BOTTOM][turret]->h;
+}
+
 //----------------------------------------------------------------------------
 Uint16 TurretSurfaces::getTipOffset(Turret turret) const
 {
