@@ -1,3 +1,6 @@
+#include <cstring>
+#include <string>
+
 #include "Configuration.h"
 
 #include "SoundFactory.h"
@@ -23,7 +26,7 @@ SoundFactory::~SoundFactory()
 }
 
 //----------------------------------------------------------------------------
-void SoundFactory::init() throw (Exception)
+void SoundFactory::init()
 {
     static const char *file[] =
     {
