@@ -125,21 +125,27 @@ int main(int argc, char** argv)
     }
     catch (Exception &e)
     {
-        std::cout << "Error initializing the game!" << std::endl
+        std::cerr << "Error initializing the game!" << std::endl
                   << e << "." << std::endl;
         return -1;
     }
 
     SDLFrameRate::setFrameRate(72);  // Always use 72 fps.
 
-    PG_Application::GetApp()->Run();
+    try
+    {
+        PG_Application::GetApp()->Run();
+    }
+    catch (Exception &e)
+    {
+        std::cerr << "Critical runtime error during the game!" << std::endl
+                  << e << "." << std::endl;
+        return -1;
+    }
 
     MenuManager::destroy();
-
     PlayerConfiguration::destroy();
-
     SurfacesBase::destroy();
-
     Tiles::destroy();
 
     if (CL_OPT::enableSound)
