@@ -244,6 +244,9 @@ protected:
 
             TurretProjectile projectile(&turret, &barrel);
 
+            turret.updateSurface();
+            projectile.updateSurface();
+
             CPPUNIT_ASSERT(!ObjectBase::isCollision(&turret, &projectile));
         }
         while (0);
@@ -259,6 +262,9 @@ protected:
 
             TurretProjectile projectile(&turret, &barrel);
 
+            turret.updateSurface();
+            projectile.updateSurface();
+
             CPPUNIT_ASSERT(!ObjectBase::isCollision(&turret, &projectile));
         }
         while (0);
@@ -274,6 +280,9 @@ protected:
 
             TurretProjectile projectile(&turret, &barrel);
 
+            turret.updateSurface();
+            projectile.updateSurface();
+
             CPPUNIT_ASSERT(!ObjectBase::isCollision(&turret, &projectile));
         }
         while (0);
@@ -289,6 +298,9 @@ protected:
 
             TurretProjectile projectile(&turret, &barrel);
 
+            turret.updateSurface();
+            projectile.updateSurface();
+
             CPPUNIT_ASSERT(!ObjectBase::isCollision(&turret, &projectile));
         }
         while (0);
